%global tclver 8.6
%global pyver 3
%global swigver swig

%global githash 0
%global shorthash %(c=%{githash}; echo ${c:0:10})

Name:           hamlib
Version:        4.5.5
Release:    1%{?dist}
Summary:        Run-time library to control radio transceivers and receivers

License:        GPL-2.0-or-later and LGPL-2.0-or-later
URL:            http://www.hamlib.org
%if "%{githash}" == "0"
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
%else
Source0:        https://github.com/Hamlib/Hamlib/archive/%{githash}/%{name}-%{shorthash}.tar.gz
%endif

Patch0:         hamlib-4.0-perl_install.patch
Patch1:         hamlib-4.0-drop-libpython.patch


BuildRequires:  automake autoconf libtool
BuildRequires:  make
BuildRequires:  gcc gcc-c++ %{?swigver}
BuildRequires:  gd-devel
BuildRequires:  doxygen
BuildRequires:  source-highlight
BuildRequires:  boost-devel
BuildRequires:  libtool-ltdl-devel
BuildRequires:  libusb1-devel
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  python%{pyver}-devel
BuildRequires:  tcl-devel
BuildRequires:  perl-devel
BuildRequires:  perl-generators
BuildRequires:  perl(ExtUtils::MakeMaker)

%{?perl_default_filter}


%description
Hamlib provides a standardized programming interface that applications
can use to send the appropriate commands to a radio.

Also included in the package is a simple radio control program 'rigctl',
which lets one control a radio transceiver or receiver, either from
command line interface or in a text-oriented interactive interface.

%package devel
Summary:        Development library to control radio transceivers and receivers
Requires:       hamlib = %{version}-%{release}
Requires:       tcl-hamlib = %{version}-%{release}

%description devel
Hamlib radio control library C development headers and libraries
for building C applications with Hamlib.

%package doc
Summary:        Documentation for the hamlib radio control library
BuildArch:      noarch

%description doc
This package provides the developers documentation for the hamlib radio
control library API.

%package c++
Summary:        Hamlib radio control library C++ binding
Requires:       hamlib = %{version}-%{release}

%description c++
Hamlib radio control library C++ language binding.

%package c++-devel
Summary:        Hamlib radio control library C++ binding development headers and libraries
Requires:       hamlib-devel = %{version}-%{release}
Requires:       hamlib-c++ = %{version}-%{release}

%description c++-devel
Hamlib radio control library C++ binding development headers and libraries
for building C++ applications with Hamlib.


%package -n perl-%{name}
Summary:        Hamlib radio control library Perl binding
Requires:       hamlib = %{version}-%{release}
Provides:       hamlib-perl = %{version}-%{release}

%description -n perl-%{name}
Hamlib PERL Language bindings to allow radio control from PERL scripts.


%package -n python%{pyver}-%{name}
Summary:        Hamlib radio control library Python binding
Requires:       hamlib = %{version}-%{release}, python%{pyver}

%description -n python%{pyver}-%{name}
Hamlib Python Language bindings to allow radio control from Python scripts.

%package -n tcl-%{name}
Summary:        Hamlib radio control library TCL binding
Requires:       hamlib = %{version}-%{release}
Provides:       hamlib-tcl = %{version}-%{release}
  
%description -n tcl-%{name}
Hamlib TCL Language bindings to allow radio control from TCL scripts.


%prep
%if "%{githash}" == "0"
%autosetup -p1
%else
%autosetup -p1 -n Hamlib-%{githash}
%endif

%build
export PYTHON=%{__python3}

autoreconf -fi

%configure \
        --disable-static \
        --with-tcl-binding \
        --with-perl-binding \
        --with-python-binding \

%make_build

make -C doc doc


%install
%make_install

mkdir -p %{buildroot}%{_docdir}/%{name}/html/search
for f in `find doc/html/ -type f -maxdepth 1`
        do install -D -m 0644 $f %{buildroot}%{_docdir}/%{name}/`echo $f | cut -d '/' -f2`
done
for f in `find doc/html/search -type f -maxdepth 1`
        do install -D -m 0644 $f %{buildroot}%{_docdir}/%{name}/html/`echo $f | cut -d '/' -f3`
 done

rm -rf __tmp_doc ; mkdir __tmp_doc
mv %{buildroot}%{_docdir}/%{name}/* __tmp_doc


find %{buildroot} -type f -name Hamlib.so -exec chmod 0755 {} ';'

find %{buildroot} -name \*.la -exec rm -f {} ';'
find %{buildroot} -type f -name pkgIndex.tcl -exec rm -f {} ';'
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'
find %{buildroot} -type f -name Hamlib.bs -exec rm -f {} ';'
find %{buildroot} -type f -name perltest.pl -exec rm -f {} ';'


%check
make V=1 check

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -p /sbin/ldconfig c++
%postun -p /sbin/ldconfig c++

%post -p /sbin/ldconfig -n tcl-hamlib
%postun -p /sbin/ldconfig -n tcl-hamlib


%files
%license COPYING
%doc AUTHORS ChangeLog PLAN README THANKS
%{_bindir}/*
%{_libdir}/libhamlib.so.*
%{_mandir}/man?/*

%files devel
%doc README.developer
%{_libdir}/libhamlib.so
%{_libdir}/tcl%{tclver}/Hamlib/hamlibtcl.so
%{_datadir}/aclocal/hamlib.m4
%dir %{_includedir}/hamlib
%{_includedir}/hamlib/ampclass.h
%{_includedir}/hamlib/amplifier.h
%{_includedir}/hamlib/amplist.h
%{_includedir}/hamlib/config.h
%{_includedir}/hamlib/rig.h
%{_includedir}/hamlib/riglist.h
%{_includedir}/hamlib/rig_dll.h
%{_includedir}/hamlib/rotator.h
%{_includedir}/hamlib/rotlist.h
%{_libdir}/pkgconfig/hamlib.pc

%files doc
%doc COPYING.LIB
%doc __tmp_doc/*

%files c++
%{_libdir}/libhamlib++.so.*

%files c++-devel
%{_libdir}/libhamlib++.so
%{_includedir}/hamlib/rigclass.h
%{_includedir}/hamlib/rotclass.h

%files -n perl-hamlib
%{perl_vendorarch}/*

%files -n python%{pyver}-%{name}
%{python3_sitearch}/*.py*
%{python3_sitearch}/_Hamlib.so
%{python3_sitearch}/__pycache__/Hamlib.*

%files -n tcl-hamlib
%{_libdir}/tcl%{tclver}/
%exclude %{_libdir}/tcl%{tclver}/Hamlib/hamlibtcl.so


%changelog
* Wed Jul 24 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - -1
- initial build
